@@ -13,9 +13,6 @@ import AVFoundation
 class RNVideoPlayer: RCTView {
 
   let processingFilters: VideoProcessingGPUFilters = VideoProcessingGPUFilters()
-  let EVENTS = (
-    SEND_PREVIEWS: "VIDEO_PROCESSING:PREVIEWS"
-  )
 
   var playerVolume: NSNumber = 0
   var player: AVPlayer! = nil
@@ -35,6 +32,8 @@ class RNVideoPlayer: RCTView {
   var _playerStartTime: CGFloat = 0
   var _playerEndTime: CGFloat = 0
   var _replay: Bool = false
+  var _rotate: Bool = false
+  var onChange: RCTBubblingEventBlock?
 
   let LOG_KEY: String = "VIDEO_PROCESSING"
 
@@ -52,6 +51,7 @@ class RNVideoPlayer: RCTView {
     set(val) {
       if val != nil {
         self._playerHeight = val as! CGFloat
+        self.frame.size.height = self._playerHeight
         filterView.frame.size.height = self._playerHeight
         print("CHANGED HEIGHT \(val)")
       }
@@ -65,6 +65,7 @@ class RNVideoPlayer: RCTView {
     set(val) {
       if val != nil {
         self._playerWidth = val as! CGFloat
+        self.frame.size.width = self._playerWidth
         filterView.frame.size.width = self._playerWidth
         print("CHANGED WIDTH \(val)")
       }
@@ -187,6 +188,28 @@ class RNVideoPlayer: RCTView {
     }
   }
 
+  var rotate: NSNumber? {
+    set(val) {
+      if val != nil {
+        self._rotate = RCTConvert.bool(val!)
+        var rotationAngle: CGFloat = 0
+        if self._rotate {
+          filterView.frame.size.width = self._playerHeight
+          filterView.frame.size.height = self._playerWidth
+          rotationAngle = CGFloat(M_PI_2)
+        } else {
+          filterView.frame.size.width = self._playerWidth
+          filterView.frame.size.height = self._playerHeight
+        }
+        self.filterView.transform = CGAffineTransform(rotationAngle: rotationAngle)
+        self.layoutIfNeeded()
+      }
+    }
+    get {
+      return nil
+    }
+  }
+
   var volume: NSNumber? {
     set(val) {
       let minValue: NSNumber = 0
@@ -258,9 +281,9 @@ class RNVideoPlayer: RCTView {
   }
 
   func onVideoCurrentTimeChange(currentTime: CGFloat) {
-    if (self.bridge != nil && self.bridge.eventDispatcher() != nil) {
+    if self.onChange != nil {
       let event = ["currentTime": currentTime]
-      self.bridge.eventDispatcher().sendAppEvent(withName: "VIDEO_PROCESSING_EVENT_CURRENT_TIME", body: event)
+      self.onChange!(event)
     }
   }
 
@@ -280,7 +303,6 @@ class RNVideoPlayer: RCTView {
       print("CHANGED playerEndTime \(self._playerEndTime)")
     }
 
-
     gpuMovie = GPUImageMovie(playerItem: playerItem)
     // gpuMovie.runBenchmark = true
     gpuMovie.playAtActualSpeed = true
@@ -288,12 +310,8 @@ class RNVideoPlayer: RCTView {
 
     filterView.frame = self.frame
 
-    filterView.frame.size.width = self._playerWidth
-    filterView.frame.size.height = self._playerHeight
-
     gpuMovie.addTarget(self.filterView)
     self.addSubview(filterView)
-    print("SUBS: \(self.subviews)")
     gpuMovie.playAtActualSpeed = true
 
     self.createPlayerObservers()
