@@ -1,12 +1,7 @@
 import React, { PropTypes, Component } from 'react';
-import {
-  requireNativeComponent,
-  DeviceEventEmitter,
-  processColor
-} from 'react-native';
+import { requireNativeComponent, processColor } from 'react-native';
 import { getActualSource } from '../utils';
 const TRIMMER_COMPONENT_NAME = 'RNTrimmerView';
-const TRIM_EVENT = 'VIDEO_PROCESSING_EVENT_TRIMMER';
 
 export class Trimmer extends Component {
 	static propTypes = {
@@ -24,19 +19,14 @@ export class Trimmer extends Component {
 	constructor(...args) {
 		super(...args);
 		this.state = {};
-		this.trimListener = null;
+		this._onChange = this._onChange.bind(this);
 	}
 
-	componentDidMount() {
-		this.trimListener = DeviceEventEmitter.addListener(TRIM_EVENT, (event) => {
-			if (typeof this.props.onChange === 'function') {
-				this.props.onChange(event);
-			}
-		});
-	}
-
-	componentWillUnmount() {
-		DeviceEventEmitter.removeListener(TRIM_EVENT, this.trimListener);
+	_onChange(event) {
+		if (!this.props.onChange) {
+			return;
+		}
+		this.props.onChange(event.nativeEvent);
 	}
 
 	render() {
@@ -49,6 +39,7 @@ export class Trimmer extends Component {
 				height={height}
 				themeColor={processColor(themeColor).toString()}
 				pointerEvents={'box-none'}
+				onChange={this._onChange}
 			/>
 		);
 	}
