@@ -1,13 +1,7 @@
 import React, { PropTypes, Component } from 'react';
-import {
-	View,
-	requireNativeComponent,
-	NativeModules,
-	DeviceEventEmitter
-} from 'react-native';
+import { View, requireNativeComponent, NativeModules } from 'react-native';
 import { getActualSource } from '../utils';
 const PLAYER_COMPONENT_NAME = 'RNVideoProcessing';
-const VIDEO_EVENT = 'VIDEO_PROCESSING_EVENT_CURRENT_TIME';
 
 const { RNVideoTrimmer } = NativeModules;
 
@@ -16,6 +10,7 @@ export class VideoPlayer extends Component {
 		source: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired,
 		play: PropTypes.bool,
 		replay: PropTypes.bool,
+		rotate: PropTypes.bool,
 		currentTime: PropTypes.number,
 		volume: PropTypes.number,
 		startTime: PropTypes.number,
@@ -29,6 +24,7 @@ export class VideoPlayer extends Component {
 	static defaultProps = {
 		play: false,
 		replay: false,
+		rotate: false,
 		volume: 0.0,
 		currentTime: 0,
 		startTime: 0,
@@ -36,22 +32,10 @@ export class VideoPlayer extends Component {
 	constructor(...args) {
 		super(...args);
 		this.state = {};
-		this.videoEventListener = null;
 		this.trim = this.trim.bind(this);
 		this.getPreviewForSecond = this.getPreviewForSecond.bind(this);
 		this.getVideoInfo = this.getVideoInfo.bind(this);
-	}
-
-	componentDidMount() {
-		this.videoEventListener = DeviceEventEmitter.addListener(VIDEO_EVENT, (event) => {
-			if (typeof this.props.onChange === 'function') {
-				this.props.onChange(event);
-			}
-		});
-	}
-
-	componentWillUnmount() {
-		DeviceEventEmitter.removeListener(VIDEO_EVENT, this.videoEventListener);
+		this._onChange = this._onChange.bind(this);
 	}
 
 	getPreviewForSecond(source, forSecond = 0) {
@@ -78,6 +62,13 @@ export class VideoPlayer extends Component {
 		});
 	}
 
+	_onChange(event) {
+		if (!this.props.onChange) {
+			return;
+		}
+		this.props.onChange(event);
+	}
+
 	trim(source, start, end) {
 		const actualSource = getActualSource(source);
 		return new Promise((resolve, reject) => {
@@ -95,6 +86,7 @@ export class VideoPlayer extends Component {
 			source,
 			play,
 			replay,
+			rotate,
 			currentTime,
 			backgroundColor,
 			startTime,
@@ -111,6 +103,7 @@ export class VideoPlayer extends Component {
 				source={actualSource}
 				play={play}
 				replay={replay}
+				rotate={rotate}
 				volume={volume}
 				playerWidth={playerWidth}
 				playerHeight={playerHeight}
@@ -118,6 +111,7 @@ export class VideoPlayer extends Component {
 				background_Color={backgroundColor}
 				startTime={startTime}
 				endTime={endTime}
+				onChange={this._onChange}
 				{...viewProps}
 			/>
 		);
